@@ -1,5 +1,5 @@
-API_PATTERN_PREFIX = "v1_"
-API_ROUTE_PREFIX = "/api/v1/"
+API_PATH_DEFAULT_PREFIX = "/api"
+API_ROUTE_NAME_PREFIX = "cube_api_v1_"
 
 DEFAULT_ROUTE_PARAMS = {
     "request_method": "POST",
